@@ -15,7 +15,8 @@ from vivarium.core.store import (
 from vivarium.core.types import (
     Processes, Topology, HierarchyPath, State, Schema, Steps, Flow)
 from vivarium.library.datum import Datum
-from vivarium.library.dict_utils import deep_merge
+from vivarium.library.dict_utils import (
+    deep_merge, deep_merge_check, deep_copy_internal)
 from vivarium.library.topology import inverse_topology
 
 
@@ -109,7 +110,9 @@ class Composite(Datum):
         config = config or {}
         super().__init__(config)
         self._schema = config.get('_schema', {})
-        _override_schemas(self._schema, self.processes)
+        processes_and_steps = deep_copy_internal(self.processes)
+        deep_merge_check(processes_and_steps, self.steps)
+        _override_schemas(self._schema, processes_and_steps)
 
     def generate_store(self, config: Optional[dict] = None) -> Store:
         config = config or {}
@@ -185,7 +188,9 @@ class Composite(Datum):
         deep_merge(self.processes, merge_processes)
         deep_merge(self.topology, merge_topology)
         self._schema.update(schema_override)
-        _override_schemas(self._schema, self.processes)
+        processes_and_steps = deep_copy_internal(self.processes)
+        deep_merge_check(processes_and_steps, self.steps)
+        _override_schemas(self._schema, processes_and_steps)
 
     def get_parameters(self) -> Dict:
         """Get the parameters for all :term:`processes`.
@@ -339,7 +344,9 @@ class Composer(metaclass=abc.ABCMeta):
         steps = self.generate_steps(config)
         flow = self.generate_flow(config)
         topology = self.generate_topology(config)
-        _override_schemas(self.schema_override, processes)
+        processes_and_steps = deep_copy_internal(processes)
+        deep_merge_check(processes_and_steps, steps)
+        _override_schemas(self.schema_override, processes_and_steps)
 
         return Composite({
             'processes': assoc_in({}, path, processes),
